@@ -21,8 +21,8 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *********************************************************************/
 #include "authenticator.h"
-#include <kcheckpass-enums.h>
 #include <config-kscreenlocker.h>
+#include <kcheckpass-enums.h>
 
 // Qt
 #include <QCoreApplication>
@@ -33,11 +33,10 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // system
 #include <errno.h>
 #include <signal.h>
-#include <sys/types.h>
 #include <sys/socket.h>
+#include <sys/types.h>
 #include <sys/wait.h>
 #include <unistd.h>
-#include <signal.h>
 
 Authenticator::Authenticator(AuthenticationMode mode, QObject *parent)
     : QObject(parent)
@@ -59,11 +58,11 @@ Authenticator::~Authenticator() = default;
 void Authenticator::tryUnlock(const QString &password)
 {
     if (isGraceLocked()) {
-        emit failed();
+        Q_EMIT failed();
         return;
     }
     m_graceLockTimer->start();
-    emit graceLockedChanged();
+    Q_EMIT graceLockedChanged();
 
     if (!m_checkPass) {
         m_checkPass = new KCheckPass(AuthenticationMode::Direct, this);
@@ -71,7 +70,7 @@ void Authenticator::tryUnlock(const QString &password)
         setupCheckPass();
     } else {
         if (!m_checkPass->isReady()) {
-            emit failed();
+            Q_EMIT failed();
             return;
         }
         m_checkPass->setPassword(password);
@@ -85,11 +84,9 @@ void Authenticator::setupCheckPass()
     connect(m_checkPass, &KCheckPass::failed, this, &Authenticator::failed);
     connect(m_checkPass, &KCheckPass::message, this, &Authenticator::message);
     connect(m_checkPass, &KCheckPass::error, this, &Authenticator::error);
-    connect(m_checkPass, &KCheckPass::destroyed, this,
-        [this] {
-            m_checkPass = nullptr;
-        }
-    );
+    connect(m_checkPass, &KCheckPass::destroyed, this, [this] {
+        m_checkPass = nullptr;
+    });
     m_checkPass->start();
 }
 
@@ -121,8 +118,9 @@ void KCheckPass::start()
     int sfd[2];
     char fdbuf[16];
 
-    if (m_notifier)
+    if (m_notifier) {
         return;
+    }
     if (::socketpair(AF_LOCAL, SOCK_STREAM, 0, sfd)) {
         cantCheck();
         return;
@@ -136,11 +134,7 @@ void KCheckPass::start()
     if (!m_pid) {
         ::close(sfd[0]);
         sprintf(fdbuf, "%d", sfd[1]);
-        execlp(QFile::encodeName(QStringLiteral(KCHECKPASS_BIN)).data(),
-               "kcheckpass",
-               "-m", "classic",
-               "-S", fdbuf,
-               (char *)nullptr);
+        execlp(QFile::encodeName(QStringLiteral(KCHECKPASS_BIN)).data(), "kcheckpass", "-m", "classic", "-S", fdbuf, (char *)nullptr);
         _exit(20);
     }
     ::close(sfd[1]);
@@ -155,18 +149,21 @@ int KCheckPass::Reader(void *buf, int count)
 {
     int ret, rlen;
 
-    for (rlen = 0; rlen < count; ) {
-      dord:
+    for (rlen = 0; rlen < count;) {
+    dord:
         ret = ::read(m_fd, (void *)((char *)buf + rlen), count - rlen);
         if (ret < 0) {
-            if (errno == EINTR)
+            if (errno == EINTR) {
                 goto dord;
-            if (errno == EAGAIN)
+            }
+            if (errno == EAGAIN) {
                 break;
+            }
             return -1;
         }
-        if (!ret)
+        if (!ret) {
             break;
+        }
         rlen += ret;
     }
     return rlen;
@@ -189,13 +186,13 @@ bool KCheckPass::GSendInt(int val)
 
 bool KCheckPass::GSendStr(const char *buf)
 {
-    int len = buf ? ::strlen (buf) + 1 : 0;
-    return GWrite(&len, sizeof(len)) && GWrite (buf, len);
+    int len = buf ? ::strlen(buf) + 1 : 0;
+    return GWrite(&len, sizeof(len)) && GWrite(buf, len);
 }
 
 bool KCheckPass::GSendArr(int len, const char *buf)
 {
-    return GWrite(&len, sizeof(len)) && GWrite (buf, len);
+    return GWrite(&len, sizeof(len)) && GWrite(buf, len);
 }
 
 bool KCheckPass::GRecvInt(int *val)
@@ -208,16 +205,18 @@ bool KCheckPass::GRecvArr(char **ret)
     int len;
     char *buf;
 
-    if (!GRecvInt(&len))
+    if (!GRecvInt(&len)) {
         return false;
+    }
     if (!len) {
         *ret = nullptr;
         return true;
     }
-    if (!(buf = (char *)::malloc (len)))
+    if (!(buf = (char *)::malloc(len))) {
         return false;
+    }
     *ret = buf;
-    if (GRead (buf, len)) {
+    if (GRead(buf, len)) {
         return true;
     } else {
         ::free(buf);
@@ -232,21 +231,23 @@ void KCheckPass::handleVerify()
     int ret;
     char *arr;
 
-    if (GRecvInt( &ret )) {
+    if (GRecvInt(&ret)) {
         switch (ret) {
         case ConvGetBinary:
-            if (!GRecvArr( &arr ))
+            if (!GRecvArr(&arr)) {
                 break;
+            }
             // FIXME: not supported
             cantCheck();
-            if (arr)
-                ::free( arr );
+            if (arr) {
+                ::free(arr);
+            }
             return;
         case ConvGetNormal:
-        case ConvGetHidden:
-        {
-            if (!GRecvArr( &arr ))
+        case ConvGetHidden: {
+            if (!GRecvArr(&arr)) {
                 break;
+            }
 
             if (m_password.isNull()) {
                 GSendStr(nullptr);
@@ -258,27 +259,30 @@ void KCheckPass::handleVerify()
 
             m_password.clear();
 
-            if (arr)
-                ::free( arr );
+            if (arr) {
+                ::free(arr);
+            }
             return;
         }
         case ConvPutInfo:
-            if (!GRecvArr( &arr ))
+            if (!GRecvArr(&arr)) {
                 break;
-            emit message(QString::fromLocal8Bit(arr));
-            ::free( arr );
+            }
+            Q_EMIT message(QString::fromLocal8Bit(arr));
+            ::free(arr);
             return;
         case ConvPutError:
-            if (!GRecvArr( &arr ))
+            if (!GRecvArr(&arr)) {
                 break;
-            emit error(QString::fromLocal8Bit(arr));
-            ::free( arr );
+            }
+            Q_EMIT error(QString::fromLocal8Bit(arr));
+            ::free(arr);
             return;
         case ConvPutAuthSucceeded:
-            emit succeeded();
+            Q_EMIT succeeded();
             return;
         case ConvPutAuthFailed:
-            emit failed();
+            Q_EMIT failed();
             return;
         case ConvPutAuthError:
             cantCheck();
@@ -303,23 +307,24 @@ void KCheckPass::handleVerify()
 
 void KCheckPass::reapVerify()
 {
-    m_notifier->setEnabled( false );
+    m_notifier->setEnabled(false);
     m_notifier->deleteLater();
     m_notifier = nullptr;
-    ::close( m_fd );
+    ::close(m_fd);
     int status;
     ::kill(m_pid, SIGUSR2);
-    while (::waitpid( m_pid, &status, 0 ) < 0)
+    while (::waitpid(m_pid, &status, 0) < 0) {
         if (errno != EINTR) { // This should not happen ...
             cantCheck();
             return;
         }
+    }
 }
 
 void KCheckPass::cantCheck()
 {
     // TODO: better signal?
-    emit failed();
+    Q_EMIT failed();
 }
 
 void KCheckPass::startAuth()
